const qixiangPayConfig = require('./config');
const {
	createMD5Sign
} = require('./utils')

/**
 * 调用七相支付接口
 * @param {Object} params 请求参数
 * @returns {Object} 支付接口返回结果
 */
async function callPayApi(params) {
	// 这里以uniCloud云函数的请求为例（uniCloud.request），你可以根据自己的需求进行修改
	try {
		// 发起请求
		const result = await uniCloud.request({
			url: `${qixiangPayConfig.api_url}/mapi.php`,
			method: "POST",
			data: params,
			header: {
				"Content-Type": "application/x-www-form-urlencoded"
			},
			dataType: "json",
		});

		// 返回结果
		return result.data;
	} catch (error) {
		throw new Error(`七相支付API请求失败: ${error.message}`);
	}
}


async function createOrder() {
	// 提取配置参数
	const {
		mch_id: pid,
		mch_key,
		notify_url,
		return_url
	} = qixiangPayConfig;

	// 1. 构造请求参数
	const params = {
		pid, // 商户 ID
		type: 'alipay', // 支付方式。alipay:支付宝,wxpay:微信支付
		out_trade_no: '20160806151343349', //generateOutTradeNo('cs'), // 商户订单号，默认为当前时间戳
		notify_url, // 异步通知地址
		return_url, // 跳转通知地址
		sitename: 'MYWEB.COM',
		name: '这是一个测试1111', // 商品名称
		money: '0.01', // 商品金额，单位：元
		clientip: '192.168.1.100', // 用户 IP 地址
		device: 'jump' // 设备类型，固定为 jump
	};
	
	// 2. 生成签名
	params.sign = createMD5Sign(params, mch_key);
	params.sign_type = "MD5"; // 签名类型
		
	// 3. 调用支付接口
	const payResult = await callPayApi(params);
	
	// 4. 返回支付链接或错误信息
	if (payResult.code === 1) {// 1为成功，其它值为失败
		return {
			code: 0,
			message: '支付链接生成成功',
			data: {
				trade_no: payResult.trade_no, // 支付订单号
				pay_url: payResult.payurl, // 支付跳转链接
				qrcode: payResult.qrcode // 二维码链接（如果有）
			}
		};
	} else {
		return {
			code: -1,
			message: payResult.msg || '支付链接生成失败',
			params
		};
	}
}

module.exports = {
	createOrder
}

// 请确保你电脑有nodejs环境，可在控制台运行以下命令测试
// node demo.js
// 或者按需导入到你的项目中使用