const crypto = require('crypto');

/**
 * 生成MD5签名
 * @param {Object} params 请求参数
 * @param {String} key 商户密钥
 * @returns {String} MD5签名
 */
function createMD5Sign(params, key) {
	// 1. 过滤掉 sign、sign_type 和空值参数
	const filteredParams = {};
	for (const [k, v] of Object.entries(params)) {
		if (k !== 'sign' && k !== 'sign_type' && v !== '' && v !== null && v !== undefined) {
			filteredParams[k] = v;
		}
	}
	
	// 2. 按照参数名的 ASCII 码从小到大排序
	const sortedParams = Object.keys(filteredParams)
		.sort()
		.map(k => `${k}=${filteredParams[k]}`)
		.join('&');
			
  // 3. 拼接商户密钥（直接拼接到末尾，不加 &key=）
  const signString = sortedParams + key;	
	
	// 4. 计算 MD5 签名
	const sign = crypto
		.createHash('md5')
		.update(signString, 'utf8')
		.digest('hex'); // 结果为小写

	return sign;
}

module.exports = {
	createMD5Sign
};